@@ -305,6 +305,8 @@ struct spvm_env {
   void (*set_pointer_length)(SPVM_ENV* env, SPVM_VALUE* stack, void* object, int32_t length);
   void* (*get_pointer_any_info)(SPVM_ENV* env, SPVM_VALUE* stack, void* object);
   void (*set_pointer_any_info)(SPVM_ENV* env, SPVM_VALUE* stack, void* object, void* any_info);
+  int32_t (*is_class)(SPVM_ENV* env, SPVM_VALUE* stack, void* object);
+  int32_t (*is_pointer_class)(SPVM_ENV* env, SPVM_VALUE* stack, void* object);
 };
 
 struct spvm_env_runtime {
@@ -392,6 +394,7 @@ struct spvm_env_runtime {
   void (*build)(void* runtime, int32_t* spvm_32bit_codes);
   int32_t (*get_class_parent_class_id)(void* runtime, int32_t class_id);
   int32_t (*get_method_required_args_length)(void* runtime, int32_t method_id);
+  int32_t (*get_class_is_pointer)(void* runtime, int32_t class_id);
 };
 
 struct spvm_env_compiler {
