@@ -97,28 +97,63 @@
 
 /* Operation id */
 enum {
+  SPVM_OP_C_ID_GRAMMAR,
+  SPVM_OP_C_ID_LIST,
+  SPVM_OP_C_ID_PUSHMARK,
+  SPVM_OP_C_ID_DO_NOTHING,
+  SPVM_OP_C_ID_NAME,
+  SPVM_OP_C_ID_DESCRIPTOR,
+  SPVM_OP_C_ID_CURRENT_CLASS,
+  SPVM_OP_C_ID_CLASS,
+  SPVM_OP_C_ID_EXTENDS,
+  SPVM_OP_C_ID_CLASS_BLOCK,
+  SPVM_OP_C_ID_END_OF_FILE,
   SPVM_OP_C_ID_IF,
   SPVM_OP_C_ID_UNLESS,
   SPVM_OP_C_ID_ELSIF,
   SPVM_OP_C_ID_ELSE,
+  SPVM_OP_C_ID_CONDITION,
+  SPVM_OP_C_ID_CONDITION_NOT,
+  SPVM_OP_C_ID_SWITCH,
+  SPVM_OP_C_ID_CASE,
+  SPVM_OP_C_ID_DEFAULT,
+  SPVM_OP_C_ID_SWITCH_CONDITION,
+  SPVM_OP_C_ID_BREAK,
   SPVM_OP_C_ID_FOR,
   SPVM_OP_C_ID_WHILE,
-  SPVM_OP_C_ID_NULL,
-  SPVM_OP_C_ID_LIST,
-  SPVM_OP_C_ID_PUSHMARK,
-  SPVM_OP_C_ID_GRAMMAR,
-  SPVM_OP_C_ID_NAME,
-  SPVM_OP_C_ID_CLASS,
+  SPVM_OP_C_ID_LOOP,
+  SPVM_OP_C_ID_LOOP_INCREMENT,
+  SPVM_OP_C_ID_LAST,
+  SPVM_OP_C_ID_NEXT,
   SPVM_OP_C_ID_MY,
   SPVM_OP_C_ID_FIELD,
   SPVM_OP_C_ID_METHOD,
   SPVM_OP_C_ID_ENUM,
-  SPVM_OP_C_ID_DESCRIPTOR,
   SPVM_OP_C_ID_ENUMERATION_VALUE,
-  SPVM_OP_C_ID_BLOCK,
   SPVM_OP_C_ID_ENUM_BLOCK,
-  SPVM_OP_C_ID_CLASS_BLOCK,
+  SPVM_OP_C_ID_BLOCK,
+  SPVM_OP_C_ID_EVAL,
   SPVM_OP_C_ID_TYPE,
+  SPVM_OP_C_ID_MUTABLE,
+  SPVM_OP_C_ID_VOID,
+  SPVM_OP_C_ID_BYTE,
+  SPVM_OP_C_ID_SHORT,
+  SPVM_OP_C_ID_INT,
+  SPVM_OP_C_ID_LONG,
+  SPVM_OP_C_ID_FLOAT,
+  SPVM_OP_C_ID_DOUBLE,
+  SPVM_OP_C_ID_STRING,
+  SPVM_OP_C_ID_OBJECT,
+  SPVM_OP_C_ID_DOT3,
+  SPVM_OP_C_ID_OF,
+  SPVM_OP_C_ID_USE,
+  SPVM_OP_C_ID_AS,
+  SPVM_OP_C_ID_ALIAS,
+  SPVM_OP_C_ID_REQUIRE,
+  SPVM_OP_C_ID_IF_REQUIRE,
+  SPVM_OP_C_ID_INIT,
+  SPVM_OP_C_ID_INTERFACE,
+  SPVM_OP_C_ID_RETURN,
   SPVM_OP_C_ID_CONSTANT,
   SPVM_OP_C_ID_INC,
   SPVM_OP_C_ID_DEC,
@@ -147,36 +182,13 @@ enum {
   SPVM_OP_C_ID_ASSIGN,
   SPVM_OP_C_ID_CALL_METHOD,
   SPVM_OP_C_ID_FIELD_ACCESS,
-  SPVM_OP_C_ID_USE,
-  SPVM_OP_C_ID_RETURN,
-  SPVM_OP_C_ID_LAST,
-  SPVM_OP_C_ID_NEXT,
-  SPVM_OP_C_ID_LOOP,
   SPVM_OP_C_ID_VAR,
   SPVM_OP_C_ID_TYPE_CAST,
   SPVM_OP_C_ID_UNDEF,
   SPVM_OP_C_ID_ARRAY_LENGTH,
-  SPVM_OP_C_ID_CONDITION,
-  SPVM_OP_C_ID_CONDITION_NOT,
   SPVM_OP_C_ID_DIE,
-  SPVM_OP_C_ID_SWITCH,
-  SPVM_OP_C_ID_CASE,
-  SPVM_OP_C_ID_DEFAULT,
-  SPVM_OP_C_ID_SWITCH_CONDITION,
-  SPVM_OP_C_ID_VOID,
-  SPVM_OP_C_ID_EVAL,
-  SPVM_OP_C_ID_BLOCK_END,
   SPVM_OP_C_ID_EXCEPTION_VAR,
   SPVM_OP_C_ID_NEW,
-  SPVM_OP_C_ID_STAB,
-  SPVM_OP_C_ID_BYTE,
-  SPVM_OP_C_ID_SHORT,
-  SPVM_OP_C_ID_INT,
-  SPVM_OP_C_ID_LONG,
-  SPVM_OP_C_ID_FLOAT,
-  SPVM_OP_C_ID_DOUBLE,
-  SPVM_OP_C_ID_STRING,
-  SPVM_OP_C_ID_OBJECT,
   SPVM_OP_C_ID_WEAKEN,
   SPVM_OP_C_ID_WEAKEN_FIELD,
   SPVM_OP_C_ID_UNWEAKEN,
@@ -185,14 +197,10 @@ enum {
   SPVM_OP_C_ID_ISWEAK_FIELD,
   SPVM_OP_C_ID_SPECIAL_ASSIGN,
   SPVM_OP_C_ID_CONCAT,
-  SPVM_OP_C_ID_SET,
-  SPVM_OP_C_ID_GET,
   SPVM_OP_C_ID_CLASS_VAR,
   SPVM_OP_C_ID_CLASS_VAR_ACCESS,
   SPVM_OP_C_ID_ARRAY_INIT,
   SPVM_OP_C_ID_BOOL,
-  SPVM_OP_C_ID_LOOP_INCREMENT,
-  SPVM_OP_C_ID_SELF,
   SPVM_OP_C_ID_CHECK_CONVERT,
   SPVM_OP_C_ID_NUMERIC_EQ,
   SPVM_OP_C_ID_NUMERIC_NE,
@@ -211,34 +219,21 @@ enum {
   SPVM_OP_C_ID_ISA,
   SPVM_OP_C_ID_IS_TYPE,
   SPVM_OP_C_ID_SEQUENCE,
-  SPVM_OP_C_ID_PRECOMPILE,
   SPVM_OP_C_ID_SCALAR,
   SPVM_OP_C_ID_ARRAY_FIELD_ACCESS,
   SPVM_OP_C_ID_CREATE_REF,
   SPVM_OP_C_ID_DEREF,
-  SPVM_OP_C_ID_DOT3,
   SPVM_OP_C_ID_STRING_LENGTH,
-  SPVM_OP_C_ID_RW,
-  SPVM_OP_C_ID_RO,
-  SPVM_OP_C_ID_WO,
-  SPVM_OP_C_ID_INIT,
-  SPVM_OP_C_ID_REQUIRE,
-  SPVM_OP_C_ID_IF_REQUIRE,
   SPVM_OP_C_ID_CURRENT_CLASS_NAME,
   SPVM_OP_C_ID_FREE_TMP,
   SPVM_OP_C_ID_REFCNT,
   SPVM_OP_C_ID_ALLOW,
-  SPVM_OP_C_ID_BREAK,
   SPVM_OP_C_ID_WARN,
   SPVM_OP_C_ID_PRINT,
   SPVM_OP_C_ID_REFOP,
   SPVM_OP_C_ID_DUMP,
   SPVM_OP_C_ID_TRUE,
   SPVM_OP_C_ID_FALSE,
-  SPVM_OP_C_ID_CURRENT_CLASS,
-  SPVM_OP_C_ID_AS,
-  SPVM_OP_C_ID_MUTABLE,
-  SPVM_OP_C_ID_END_OF_FILE,
   SPVM_OP_C_ID_DIVIDE_UNSIGNED_INT,
   SPVM_OP_C_ID_DIVIDE_UNSIGNED_LONG,
   SPVM_OP_C_ID_REMAINDER_UNSIGNED_INT,
@@ -247,18 +242,11 @@ enum {
   SPVM_OP_C_ID_IS_READ_ONLY,
   SPVM_OP_C_ID_MAKE_READ_ONLY,
   SPVM_OP_C_ID_COPY,
-  SPVM_OP_C_ID_INTERFACE,
   SPVM_OP_C_ID_HAS_IMPL,
-  SPVM_OP_C_ID_ELEMENT,
-  SPVM_OP_C_ID_OARRAY,
-  SPVM_OP_C_ID_ALIAS,
-  SPVM_OP_C_ID_OF,
-  SPVM_OP_C_ID_REQUIRED,
   SPVM_OP_C_ID_CLASS_ID,
   SPVM_OP_C_ID_ERROR_CODE,
   SPVM_OP_C_ID_SET_ERROR_CODE,
   SPVM_OP_C_ID_ERROR,
-  SPVM_OP_C_ID_EXTENDS,
 };
 
 const char* const* SPVM_OP_C_ID_NAMES(void);
